Class: Google::Apis::ApikeysV2::V2LookupKeyResponse
- Inherits:
-
Object
- Object
- Google::Apis::ApikeysV2::V2LookupKeyResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apikeys_v2/classes.rb,
lib/google/apis/apikeys_v2/representations.rb,
lib/google/apis/apikeys_v2/representations.rb
Overview
Response message for LookupKey method.
Instance Attribute Summary collapse
-
#name ⇒ String
The resource name of the API key.
-
#parent ⇒ String
The project that owns the key with the value specified in the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ V2LookupKeyResponse
constructor
A new instance of V2LookupKeyResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ V2LookupKeyResponse
Returns a new instance of V2LookupKeyResponse.
393 394 395 |
# File 'lib/google/apis/apikeys_v2/classes.rb', line 393 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The resource name of the API key. If the API key has been purged, resource
name is empty.
Corresponds to the JSON property name
386 387 388 |
# File 'lib/google/apis/apikeys_v2/classes.rb', line 386 def name @name end |
#parent ⇒ String
The project that owns the key with the value specified in the request.
Corresponds to the JSON property parent
391 392 393 |
# File 'lib/google/apis/apikeys_v2/classes.rb', line 391 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
398 399 400 401 |
# File 'lib/google/apis/apikeys_v2/classes.rb', line 398 def update!(**args) @name = args[:name] if args.key?(:name) @parent = args[:parent] if args.key?(:parent) end |